@@ -17,19 +17,33 @@ class RedisClient(ClientModel):
         )
         super().__init__(*args, **kwargs)
 
-    def set(
+    def hset(
         self,
-        arrayName:str,
+        array_name:str,
         key:str,
         value:str
     ):
-        self.redis.hset(arrayName, key, value)
+        self.redis.hset(array_name, key, value)
 
-    def get(self, arrayName:str) -> list:
-        return self.redis.hgetall(arrayName)
+    def hgetall(self, array_name:str) -> list:
+        return self.redis.hgetall(array_name)
 
-    def _getRedisClient(self) -> redis.Redis:
+    def get_redis(self) -> redis.Redis:
         return self.redis
 
-    def getHost(self) -> str:
+    def get_host(self) -> str:
         return self.host
+
+    def get_port(self) -> str:
+        return self.port
+
+    def get_db(self) -> str:
+        return self.db
+
+    def set_dict_using_global_selector(self, global_selector:str, array_name:str, set_item_key:str):
+        array = self.hgetall(array_name)
+        for key in array:
+            if key.startswith(global_selector):
+                self.__setitem__(set_item_key, array[key])
+                return
+        raise KeyError("Key not found")
