@@ -1,19 +1,16 @@
 #!/usr/bin/python3.6
 # from . import connector
-from site24x7_plugin_helper.connector.database_client import DatabaseClient
+from site24x7_plugin_helper.connector.database_client import DatabaseClient as Client
 import sys
 import os
 import json
-import argparse
+#import argparse
 from subprocess import call
-# import logging
-# logger = logging.getLogger(__name__)
-# logger.setLevel(logging.INFO)
-# handler = logging.FileHandler('/tmp/plugin.log')
-# logger.info(msg="test")
-# breakpoint()
 passDbConnection = True
 
+class DatabaseClient(Client):
+    def databaseType(self):
+        return "MSSQL"
 
 if __name__ == "__main__":
     # server infos are given as arguments
@@ -22,8 +19,8 @@ if __name__ == "__main__":
     username = sys.argv[3]
     password = sys.argv[4]
     driverLocation = sys.argv[5] # /opt/microsoft/msodbcsql17/lib64/libmsodbcsql-17.5.so.1.1
-    query = sys.argv[6] 
-    thisPluginName = sys.argv[7] 
+    query = sys.argv[6]
+    thisPluginName = sys.argv[7]
     cache = {
         "server":server,
         "database":database,
@@ -39,7 +36,7 @@ if __name__ == "__main__":
         print("connnected")
         # existing query that returns all rows from the table for caching
         # 'EXEC [Ultramerchant].dbo.pr_membership_credit_billing_stats_24x7_monitor_sel'
-        rows = DatabaseClient.fetchall(cursor, query)
+        rows = DatabaseClient.fetchall(query)
         for i in range(len(rows)):
             key = rows[i][1]
             value = rows[i][2]
@@ -50,7 +47,7 @@ if __name__ == "__main__":
     
     # save cache to file as thisPluginName 
     cacheFileName = "/" + thisPluginName + ".cache" # 
-    open(cacheFileName, 'w').write(
+    open(cacheFileName, 'w', encoding='utf8').write(
         json.dumps(cache, indent=4)
     )
     print(json.dumps(cache, indent=4, sort_keys=True))
@@ -69,7 +66,7 @@ if __name__ == "__main__":
     # create a python file if not exists
     if not os.path.isfile(fileDestination):
         call(f"touch {fileDestination}", shell=True)
-    open(fileDestination, 'w').write(f'''#!/usr/bin/python3.6
+    open(fileDestination, 'w', encoding="utf8").write(f'''#!/usr/bin/python3.6
 import json
 from site24x7_plugin_helper.utils.util import guessMetricByType
 cacheData = json.loads(open("{cacheFileName}").read())
